summaryrefslogtreecommitdiffstats
path: root/src/kpowersave.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kpowersave.cpp')
-rw-r--r--src/kpowersave.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/kpowersave.cpp b/src/kpowersave.cpp
index 92cddc5..8f92d54 100644
--- a/src/kpowersave.cpp
+++ b/src/kpowersave.cpp
@@ -67,7 +67,7 @@ kpowersave::kpowersave( bool force_acpi_check, bool trace_func ) : KSystemTray(0
resume_result = 0;
- config = KGlobal::config();
+ config = TDEGlobal::config();
config->setGroup("General");
if(!config->readBoolEntry("AlreadyStarted", false) || force_acpi_check){
config->writeEntry("AlreadyStarted", true);
@@ -510,7 +510,7 @@ void kpowersave::updateTooltip(){
/*!
* \b TQT_SLOT to starts the Yast2-power-management module. This called by the menuentry
* with ID \ref YAST_MODULE_MENU_ID, named "Start YaST2 Power Management Module".
* It create a new KProcess and execute "/sbin/yast2 power-management" with tdesu.
*/
void kpowersave::do_config(){
kdDebugFuncIn(trace);
@@ -518,12 +518,12 @@ void kpowersave::do_config(){
#ifdef ENABLE_YAST_ENTRY
delete yast2;
- yast2 = new KProcess;
+ yast2 = new TDEProcess;
*yast2 << "tdesu" << "--nonewdcop" << "/sbin/yast2" << "power-management";
- connect(yast2, TQT_SIGNAL(processExited(KProcess *)),
- TQT_SLOT(slotConfigProcessExited(KProcess *)));
- if(!yast2->start(KProcess::NotifyOnExit))
+ connect(yast2, TQT_SIGNAL(processExited(TDEProcess *)),
+ TQT_SLOT(slotConfigProcessExited(TDEProcess *)));
+ if(!yast2->start(TDEProcess::NotifyOnExit))
{
delete yast2;
yast2 = NULL;
@@ -648,10 +648,10 @@ void kpowersave::observeConfigDlg(){
}
/*!
* \b TQT_SLOT which called from \ref do_config() if the 'tdesu yast2' KProcess exited.
* This function control the return value and display if needed a errormessage on failure.
*/
-void kpowersave::slotConfigProcessExited(KProcess *proc){
+void kpowersave::slotConfigProcessExited(TDEProcess *proc){
kdDebugFuncIn(trace);
#ifdef ENABLE_YAST_ENTRY
@@ -510,7 +510,7 @@ void kpowersave::updateTooltip(){
* \b TQT_SLOT to starts the Yast2-power-management module. This called by the menuentry
* with ID \ref YAST_MODULE_MENU_ID, named "Start YaST2 Power Management Module".
- * It create a new KProcess and execute "/sbin/yast2 power-management" with tdesu.
+ * It create a new TDEProcess and execute "/sbin/yast2 power-management" with tdesu.
*/
void kpowersave::do_config(){
@@ -648,10 +648,10 @@ void kpowersave::observeConfigDlg(){
}
/*!
- * \b TQT_SLOT which called from \ref do_config() if the 'tdesu yast2' KProcess exited.
+ * \b TQT_SLOT which called from \ref do_config() if the 'tdesu yast2' TDEProcess exited.
* This function control the return value and display if needed a errormessage on failure.
*/